graph close _all

****************
****************
* BEA
* fixed asset
* tables
****************
****************

use "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/bea_fixed_tables.dta", clear
collapse (sum) INOM_E* INOM_S* INOM_R* INOM_A* KNOM_E* KNOM_S* KNOM_R* KNOM_A*, by(fyear klemsind)
sort klemsind fyear
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/bea_investment_collapsed_to_klems.dta", replace

use "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/bea_fixed_tables.dta", clear
bys fyear klemsind: keep if _n==1
keep fyear klemsind hallgroup ff_name
sort klemsind fyear
merge 1:1 klemsind fyear using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/bea_investment_collapsed_to_klems.dta"
drop _merge
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/bea_investment_collapsed_to_klems.dta", replace

****************
****************
* KLEMS
* productivity
* dta
****************
****************

use "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/klems_wip.dta", replace

* Share of nominal value added
gen 		nomVA = nomY - nomE - nomM - nomS 											if fyear >= 1998
replace 	nomVA = nomY - nomE - nomM - nomS 											if fyear <  1998 & ( klemsind >= 311 & klemsind <= 339 )
replace 	nomVA = nomY - nomEMS 					 									if fyear <  1998 & ( klemsind <  311 | klemsind >  339 )
bys fyear: egen aggnomVA = total(nomVA)
bys fyear: egen aggnomY = total(nomY)
gen sharenomVA = nomVA/aggnomVA
gen dummy = sharenomVA if fyear == 2001
bys klemsind: egen sharenomVA2001 = max(dummy)
drop dummy

* Create a price index for cogs (PX ex-capital price)
xtset klemsind fyear
gen 		PCOGS = (((PL)^(sL))*((PE)^(sE))*((PM)^(sM))*((PS)^(sS)))^(1/(sL+sE+sM+sS)) if fyear >= 1998
replace 	PCOGS = (((PL)^(sL))*((PE)^(sE))*((PM)^(sM))*((PS)^(sS)))^(1/(sL+sE+sM+sS)) if fyear <  1998 & ( klemsind >= 311 & klemsind <= 339 )
replace 	PCOGS = (((PL)^(sL))*((PEMS)^(sEMS)))^(1/(sL+sEMS)) 				      	if fyear <  1998 & ( klemsind <  311 | klemsind >  339 )

save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/intermediate_data.dta", replace

* Merge to BEA data
sort fyear klemsind
merge 1:1 fyear klemsind using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/bea_investment_collapsed_to_klems.dta"
drop _merge
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/intermediate_data.dta", replace

****************
****************
* Compustat data
****************
****************

use if fyear >= 1974 & fyear <= 2016 using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/annual_compustat.dta", clear

*******************
* Data merges
*******************

****** Add other industry classifications
merge 1:1 gvkey fyear using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/other_industry_classifications.dta"
drop _merge

****** Add aggregate data
merge m:1 fyear klemsind using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/intermediate_data.dta"
drop if _merge == 2
drop _merge

*******************
* Variable creation
*******************

gen naics_3d 		= substr(naics,1,3)
gen sector 			= substr(sic,1,3)
gen mv 				= prcc_f*csho

*******************
* Sample selection
*******************

****** Non-missing 3-digit naics code
****** This affects primarily the pre-1985 data
keep if 	   ~strmatch(naics,"")
keep if 		strlen(naics_3d) > 2

***** Firms not classified as multi-nationals
keep if 	   ~strmatch(naics_3d,"999")

***** Domestically incorporated firms
keep if 	    strmatch(fic,"USA")

***** Not a fund, trust or other financial vehicle
*keep if 	   ~strmatch(naics_3d,"525")

***** Observations meets certain balance sheet criteria
keep if 	   ~missing(sale)
keep if 	    sale 		> 0
keep if 	   ~missing(at)
keep if 		at   		> 1

*keep if       ~missing(ppegt) 
*keep if 		ppegt 		> 5

*keep if 	   ~missing(mv)
*keep if 	   ~missing(ebitda)

*keep if 	   ~missing(intan)
*keep if 	   ~missing(k_int_org)
*keep if 	   ~missing(k_int_know)

***** KLEMS industries where there are more than 5 observations per year from 1987 to 2015

preserve
	gen numfirms = 1
	collapse (sum) numfirms, by(fyear klemsind)
	keep if fyear >= 1987 & fyear <= 2015
	bys klemsind: egen minfirms = min(numfirms)
	bys klemsind: keep if _n == 1
	replace minfirms = 0 if missing(minfirms)
	gen to_drop = minfirms <= 5
	keep klemsind to_drop
	sort klemsind
	save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/klems_to_drop.dta", replace
restore
sort klemsind
merge m:1 klemsind using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/klems_to_drop.dta"
tab klemsind to_drop
drop _merge

keep if 	   ~to_drop

drop to_drop

***************************
***************************
* Additional details on 
* industry classification
***************************
***************************

* Five broad groups of sectors
gen major5 	   = 5	
replace major5 = 1 if strpos(ff_name,"Retail") 	 | strpos(ff_name,"Agric")
replace major5 = 4 if strpos(ff_name,"Manuf") 	 | strpos(ff_name,"Utilit")  | strpos(ff_name,"Minin")
replace major5 = 2 if strpos(ff_name,"software") | strpos(ff_name,"Telecom")
replace major5 = 3 if strpos(ff_name,"Healthc")
lab def labff5 1 "Consumer" 4 "Manufacturing" 2 "High-tech" 3 "Healthcare" 5 "Other", replace
lab values major5 labff5

* Re-order the 12 sectors
encode ff_name, gen(dummy)
recode dummy																		///																		///
(5  =  2   "IT & Software"								)							///
(4  =  4   "Healthcare" 								)							///
(12 =  1   "Wholesale and Retail"						) 							///	
(9  =  3   "Telecoms and Broadcasting"					) 							///
(6  =  5   "Manufacturing"								) 							///
(3  =  7   "Finance"									) 							///
(10 =  8   "Transportation and Warehousing"				) 							///
(8  =  6   "Others (mostly services)"				 	) 							///
(7  =  9   "Mining and Oil & Gas"					    ) 							///
(11 =  10  "Utilities"									) 							///
(1  =  11  "Agriculture"								) 							///
(2  =  12  "Construction, Real Estate and Leasing"		) 							///
, gen(ffindex)
drop dummy

* Additional value added weights
preserve
	keep if fyear == 2001
	bys klemsind: keep if _n==1
	egen dummy = total(sharenomVA2001)
	replace sharenomVA2001 = sharenomVA2001/dummy
	drop dummy
	bys major5: egen major5w = total(sharenomVA2001)
	bys major5 ff_name: egen ff_namew = total(sharenomVA2001)
	bys hallgroup: egen hallgroupw = total(sharenomVA2001)
	keep klemsind sharenomVA2001 major5w ff_namew hallgroupw
	sort klemsind
	save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore
sort klemsind
drop sharenomVA2001 
merge m:1 klemsind using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta"
drop _merge

***************************
***************************
* Firm age
***************************
***************************

sort gvkey
merge m:1 gvkey using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/age.dta"
drop if _merge == 2
drop _merge

***************************
***************************
* Housekeeping
***************************
***************************

* Save to a panel
destring gvkey, gen(gvkey_num)
drop gvkey
gen gvkey = gvkey_num
drop gvkey_num
sort gvkey fyear
count
sort cusip
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/panel.dta", replace
