use "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/input/panel.dta", clear

* Same range of years
keep if fyear >= 2005 & fyear <= 2012

* Variables used in the regression
egen BD 			= rowtotal(dlc dltt)
gen FDTA    		= BD/at
gen STLTA    		= dlc/at
gen logEMP 			= log(emp)
gen AGE1 			= fyear - year1
gen AGE2 			= fyear - first_year_crsp
gen AGE3 			= fyear - founding_year
gen COLLAT  		= ppegt/at
gen PROFIT  		= niadj/at
gen PROD    		= niadj/(1000*emp)
gen CASHTA 			= ch/at
gen NETFDTA 		= FDTA - CASHTA
egen ind_by_year 	= group(klemsind fyear)

univar AGE*

* Different age measures
/*
reghdfe FDTA AGE1 logEMP COLLAT PROFIT PROD, absorb(ind_by_year) vce(robust)
reghdfe FDTA AGE2 logEMP COLLAT PROFIT PROD, absorb(ind_by_year) vce(robust)
reghdfe FDTA AGE3 logEMP COLLAT PROFIT PROD, absorb(ind_by_year) vce(robust)
gen dummy = e(sample)
reghdfe FDTA AGE1 logEMP COLLAT PROFIT PROD if dummy, absorb(ind_by_year) vce(robust)
reghdfe FDTA AGE2 logEMP COLLAT PROFIT PROD if dummy, absorb(ind_by_year) vce(robust)
*/

* Use major-5 instead of major-12 classification; drop "Others" and "Healthcare" sector
replace ffindex = major5

* Comparison of age effects by industries
* All industries together
preserve
tab ffindex
reghdfe FDTA AGE3 c.AGE3#c.AGE3 logEMP COLLAT PROFIT PROD, absorb(indyearfe=ind_by_year) vce(robust)
qui su FDTA if e(sample)
gen meanlev = r(mean)
margins if e(sample), at(AGE3 = (0(3)36))
mat def A = r(table)
gen age = .
gen effect = .
gen ul = .
gen ll = .
local counter = 1
forvalues k=0(3)36{
	di "`counter'"
	replace age = `k' if _n == `counter'
	replace effect = A[1,`counter'] if age == `k'
	replace ll = A[5,`counter'] if age == `k'
	replace ul = A[6,`counter'] if age == `k'
	local counter = `counter'+1
}
keep if ~missing(age)
keep age effect ul ll meanlev
su effect
replace effect = effect - r(mean) + meanlev
replace ul = ul - r(mean) + meanlev
replace ll = ll - r(mean) + meanlev
gen ffindex = 0
sort ffindex age
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore

* Consumer goods // wholesale & retail trade
preserve
keep if ffindex == 1
tab ffindex
reghdfe FDTA AGE3 c.AGE3#c.AGE3 logEMP COLLAT PROFIT PROD, absorb(indyearfe=ind_by_year) vce(robust)
qui su FDTA if e(sample)
gen meanlev = r(mean)
margins if e(sample), at(AGE3 = (0(3)36))
mat def A = r(table)
gen age = .
gen effect = .
gen ul = .
gen ll = .
local counter = 1
forvalues k=0(3)36{
	di "`counter'"
	replace age = `k' if _n == `counter'
	replace effect = A[1,`counter'] if age == `k'
	replace ll = A[5,`counter'] if age == `k'
	replace ul = A[6,`counter'] if age == `k'
	local counter = `counter'+1
}
keep if ~missing(age)
keep ffindex age effect ul ll meanlev
su effect
replace effect = effect - r(mean) + meanlev
replace ul = ul - r(mean) + meanlev
replace ll = ll - r(mean) + meanlev
sort ffindex age
append using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta"
sort ffindex age
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore

* Tech
preserve
keep if ffindex == 2
tab ffindex
reghdfe FDTA AGE3 c.AGE3#c.AGE3 logEMP COLLAT PROFIT PROD, absorb(indyearfe=ind_by_year) vce(robust)
qui su FDTA if e(sample)
gen meanlev = r(mean)
margins if e(sample), at(AGE3 = (0(3)36))
mat def A = r(table)
gen age = .
gen effect = .
gen ul = .
gen ll = .
local counter = 1
forvalues k=0(3)36{
	di "`counter'"
	replace age = `k' if _n == `counter'
	replace effect = A[1,`counter'] if age == `k'
	replace ll = A[5,`counter'] if age == `k'
	replace ul = A[6,`counter'] if age == `k'
	local counter = `counter'+1
}
keep if ~missing(age)
keep ffindex age effect ul ll meanlev
su effect
replace effect = effect - r(mean) + meanlev
replace ul = ul - r(mean) + meanlev
replace ll = ll - r(mean) + meanlev
sort ffindex age
append using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta"
sort ffindex age
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore

* Healthcare
preserve
keep if ffindex == 3
tab ffindex
reghdfe FDTA AGE3 c.AGE3#c.AGE3 logEMP COLLAT PROFIT PROD, absorb(indyearfe=ind_by_year) vce(robust)
qui su FDTA if e(sample)
gen meanlev = r(mean)
margins if e(sample), at(AGE3 = (0(3)36))
mat def A = r(table)
gen age = .
gen effect = .
gen ul = .
gen ll = .
local counter = 1
forvalues k=0(3)36{
	di "`counter'"
	replace age = `k' if _n == `counter'
	replace effect = A[1,`counter'] if age == `k'
	replace ll = A[5,`counter'] if age == `k'
	replace ul = A[6,`counter'] if age == `k'
	local counter = `counter'+1
}
keep if ~missing(age)
keep ffindex age effect ul ll meanlev
su effect
replace effect = effect - r(mean) + meanlev
replace ul = ul - r(mean) + meanlev
replace ll = ll - r(mean) + meanlev
sort ffindex age
append using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta"
sort ffindex age
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore

* Manufacturing
preserve
keep if ffindex == 4
tab ffindex
reghdfe FDTA AGE3 c.AGE3#c.AGE3 logEMP COLLAT PROFIT PROD, absorb(indyearfe=ind_by_year) vce(robust)
qui su FDTA if e(sample)
gen meanlev = r(mean)
margins if e(sample), at(AGE3 = (0(3)36))
mat def A = r(table)
gen age = .
gen effect = .
gen ul = .
gen ll = .
local counter = 1
forvalues k=0(3)36{
	di "`counter'"
	replace age = `k' if _n == `counter'
	replace effect = A[1,`counter'] if age == `k'
	replace ll = A[5,`counter'] if age == `k'
	replace ul = A[6,`counter'] if age == `k'
	local counter = `counter'+1
}
keep if ~missing(age)
keep ffindex age effect ul ll meanlev
su effect
replace effect = effect - r(mean) + meanlev
replace ul = ul - r(mean) + meanlev
replace ll = ll - r(mean) + meanlev
sort ffindex age
append using "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta"
sort ffindex age
save "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", replace
restore

tab ffindex

use "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/temp/dummy.dta", clear
xtset ffindex age
twoway ///
	(line effect age if ffindex == 0, mcolor(gs5) lpat(solid)) ///
	(rarea ul ll age if ffindex == 0, lwidth(0) fcolor(gs5%30) fintensity(inten30)) ///
	(line effect age if ffindex == 1, lpat(longdash)) ///
	(line effect age if ffindex == 2, lpat(longdash)) ///
	(line effect age if ffindex == 4, lpat(longdash)) ///
	, ///
	ylab(0.1(0.05)0.3) ///
	xlab(0(3)36) ///
	ytitle("Gross overall leverage") ///
	legend(ring(1) position(6) cols(2) order(1 "All sectors (with 95% c.i.)" ///
				 3 "Wholesale and retail" ///
				 4 "High-tech" ///
				 5 "Manufacturing" ///
				 )) ///
				 
graph export "~/Dropbox/Work/Discussions/Sebnem - Leverage and life-cycle/tex/fig10.pdf", replace
	
